@@ -17,7 +17,7 @@
 #if __has_include(<charconv>)
 #include <charconv>
 #endif
-#if __cpp_concepts >= 202002L
+#if defined(__cpp_concepts) && __cpp_concepts >= 202002L
 #include <concepts>
 #endif
 #endif
@@ -82,21 +82,21 @@ template <size_t Id, typename Name = void> struct captured_content {
 		template <typename It = Iterator> constexpr CTRE_FORCE_INLINE const auto * data_unsafe() const noexcept {
 			static_assert(!is_reverse_iterator<It>, "Iterator in your capture must not be reverse!");
 			
-			#if __cpp_char8_t >= 201811
+#if defined(__cpp_char8_t) && __cpp_char8_t >= 201811
 			if constexpr (std::is_same_v<Iterator, utf8_iterator>) {
 				return _begin.ptr;
 			} else { // I'm doing this to avoid warning about dead code
-			#endif
+#endif
 			
-			#ifdef _MSC_VER
+#ifdef _MSC_VER
 			return std::to_address(_begin); // I'm enabling this only for MSVC for now, as some clang old versions with various libraries (random combinations) has different problems
-			#else
+#else
 			return &*_begin; 
-			#endif
+#endif
 			
-			#if __cpp_char8_t >= 201811
+#if defined(__cpp_char8_t) && __cpp_char8_t >= 201811
 			}
-			#endif
+#endif
 		}
 		
 		template <typename It = Iterator> constexpr CTRE_FORCE_INLINE const auto * data() const noexcept {
@@ -112,15 +112,15 @@ template <size_t Id, typename Name = void> struct captured_content {
 		}
 		
 		constexpr CTRE_FORCE_INLINE size_t unit_size() const noexcept {
-			#if __cpp_char8_t >= 201811
+#if defined(__cpp_char8_t) && __cpp_char8_t >= 201811
 			if constexpr (std::is_same_v<Iterator, utf8_iterator>) {
 				return static_cast<size_t>(std::distance(_begin.ptr, _end.ptr));
 			} else {
 				return static_cast<size_t>(std::distance(begin(), end()));
 			}
-			#else
+#else
 			return static_cast<size_t>(std::distance(begin(), end()));
-			#endif
+#endif
 		}
 		
 #if __has_include(<charconv>)
@@ -161,15 +161,15 @@ template <size_t Id, typename Name = void> struct captured_content {
 		}
 		
 		constexpr CTRE_FORCE_INLINE std::basic_string<char_type> to_string() const noexcept {
-			#if __cpp_char8_t >= 201811
+#if defined(__cpp_char8_t) && __cpp_char8_t >= 201811
 			if constexpr (std::is_same_v<Iterator, utf8_iterator>) {
 				return std::basic_string<char_type>(data_unsafe(), static_cast<size_t>(unit_size()));
 			} else {
 				return std::basic_string<char_type>(begin(), end());
 			}
-			#else
+#else
 			return std::basic_string<char_type>(begin(), end());
-			#endif
+#endif
 		}
 		
 		constexpr CTRE_FORCE_INLINE auto str() const noexcept {
@@ -221,7 +221,7 @@ template <size_t Id, typename Name = void> struct captured_content {
 	};
 };
 
-#if __cpp_concepts >= 202002L
+#if defined(__cpp_concepts) && __cpp_concepts >= 202002L
 template <typename T> concept capture_group = requires(const T & cap) {
 	{ T::get_id() } -> std::same_as<size_t>;
 	{ cap.view() };
@@ -537,7 +537,7 @@ template <typename Iterator, typename... Captures> struct is_regex_results_t<reg
 
 template <typename T> constexpr bool is_regex_results_v = is_regex_results_t<T>();
 
-#if __cpp_concepts >= 201907L
+#if defined(__cpp_concepts) && __cpp_concepts >= 201907L
 template <typename T> concept capture_groups = is_regex_results_v<T>;
 #endif
 
